<?php

namespace Drupal\edlp_studio\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\User\UserDataInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

use Drupal\edlp_studio\Entity\Chutier;


/**
 * Class StudioUIController.
 */
class StudioUIController extends ControllerBase {

  protected $user;
  protected $userdata;

  /**
   * Class constructor.
   */
  public function __construct(AccountInterface $account, UserDataInterface $userdata) {
    $this->user = $account;
    $this->userdata = $userdata;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
      // Load the service required to construct this class.
      $container->get('current_user'),
      $container->get('user.data')
    );
  }

  /**
   * Studio-ui.
   *
   * @return array
   *   Return renderable array.
   */
  public function StudioUI() {
    return $this->buildUI();
  }

  /**
   * Studio-ui.
   *
   * @return array
   *   Return renderable array.
   */
  public function StudioUIJson() {
    $renderable = $this->buildStudioUI();
    $rendered = render($renderable);

    // JSON
    $response = new JsonResponse();
    $response->setData([
      'rendered'=> $rendered,
    ]);
    return $response;

  }

  public function StudioChutierUIJson(){
    $renderable = $this->buildChutierUI();
    $rendered = render($renderable);

    // JSON
    $response = new JsonResponse();
    $response->setData([
      'rendered'=> $rendered,
    ]);
    return $response;
  }

  private function buildStudioUI(){
    return [
      '#theme' => 'edlp_studio_ui',
      '#chutier_ui' => $this->buildChutierUI(),
      '#composition_ui' => $this->buildCompostionUI(),
    ];
  }

  private function buildChutierUI(){
    // get his docs in chutier
    $documents_nids = Chutier::getUserChutiersContents($this->user->id());
    // dpm($documents_nids);

    $documents = entity_load_multiple('node', $documents_nids);

    // build content renderable array
    $chutier_ui = array(
      "#theme"=>'edlp_chutier_ui',
      '#title' => t('Chutier'),
      "#document_nodes" => $documents,
      '#uid' => $this->user->id(),
    );

    return $chutier_ui;
  }

  private function buildCompostionUI(){
    // TODO: get compositions
    // TODO: add compositions theme, preprocess, twig template to studio module
    // TODO: build content renderable array
    $composition_ui = array(
      "#theme"=>'edlp_compostion_ui',
      "#title" => t('Composition'),
      "#compositions" => array('#markup'=>'TODO : compositions UI'),
    );

    return $composition_ui;
  }
}
